Struct google_sheets4::api::AddConditionalFormatRuleRequest [−][src]
Adds a new conditional format rule at the given index. All subsequent rules’ indexes are incremented.
This type is not used in any activity, and only used as part of another schema.
Fields
index: Option<i32>The zero-based index where the rule should be inserted.
rule: Option<ConditionalFormatRule>The rule to add.