Struct google_sheets4::api::AutoResizeDimensionsRequest[][src]

pub struct AutoResizeDimensionsRequest {
    pub data_source_sheet_dimensions: Option<DataSourceSheetDimensionRange>,
    pub dimensions: Option<DimensionRange>,
}

Automatically resizes one or more dimensions based on the contents of the cells in that dimension.

This type is not used in any activity, and only used as part of another schema.

Fields

data_source_sheet_dimensions: Option<DataSourceSheetDimensionRange>

The dimensions on a data source sheet to automatically resize.

dimensions: Option<DimensionRange>

The dimensions to automatically resize.