Struct google_sheets4::api::BatchClearValuesByDataFilterResponse [−][src]
The response when clearing a range of values selected with DataFilters in a spreadsheet.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
cleared_ranges: Option<Vec<String>>The ranges that were cleared, in A1 notation. If the requests are for an unbounded range or a ranger larger than the bounds of the sheet, this is the actual ranges that were cleared, bounded to the sheet’s limits.
spreadsheet_id: Option<String>The spreadsheet the updates were applied to.