Struct google_sheets4::api::BatchUpdateValuesByDataFilterRequest[][src]

pub struct BatchUpdateValuesByDataFilterRequest {
    pub data: Option<Vec<DataFilterValueRange>>,
    pub include_values_in_response: Option<bool>,
    pub response_date_time_render_option: Option<String>,
    pub response_value_render_option: Option<String>,
    pub value_input_option: Option<String>,
}

The request for updating more than one range of values in a spreadsheet.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

data: Option<Vec<DataFilterValueRange>>

The new values to apply to the spreadsheet. If more than one range is matched by the specified DataFilter the specified values are applied to all of those ranges.

include_values_in_response: Option<bool>

Determines if the update response should include the values of the cells that were updated. By default, responses do not include the updated values. The updatedData field within each of the BatchUpdateValuesResponse.responses contains the updated values. If the range to write was larger than the range actually written, the response includes all values in the requested range (excluding trailing empty rows and columns).

response_date_time_render_option: Option<String>

Determines how dates, times, and durations in the response should be rendered. This is ignored if response_value_render_option is FORMATTED_VALUE. The default dateTime render option is DateTimeRenderOption.SERIAL_NUMBER.

response_value_render_option: Option<String>

Determines how values in the response should be rendered. The default render option is ValueRenderOption.FORMATTED_VALUE.

value_input_option: Option<String>

How the input data should be interpreted.