Struct google_sheets4::api::BatchUpdateValuesByDataFilterResponse[][src]

pub struct BatchUpdateValuesByDataFilterResponse {
    pub responses: Option<Vec<UpdateValuesByDataFilterResponse>>,
    pub spreadsheet_id: Option<String>,
    pub total_updated_cells: Option<i32>,
    pub total_updated_columns: Option<i32>,
    pub total_updated_rows: Option<i32>,
    pub total_updated_sheets: Option<i32>,
}

The response when updating a range of values in a spreadsheet.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

responses: Option<Vec<UpdateValuesByDataFilterResponse>>

The response for each range updated.

spreadsheet_id: Option<String>

The spreadsheet the updates were applied to.

total_updated_cells: Option<i32>

The total number of cells updated.

total_updated_columns: Option<i32>

The total number of columns where at least one cell in the column was updated.

total_updated_rows: Option<i32>

The total number of rows where at least one cell in the row was updated.

total_updated_sheets: Option<i32>

The total number of sheets where at least one cell in the sheet was updated.