Struct google_sheets4::api::CandlestickChartSpec[][src]

pub struct CandlestickChartSpec {
    pub data: Option<Vec<CandlestickData>>,
    pub domain: Option<CandlestickDomain>,
}

A candlestick chart.

This type is not used in any activity, and only used as part of another schema.

Fields

data: Option<Vec<CandlestickData>>

The Candlestick chart data. Only one CandlestickData is supported.

domain: Option<CandlestickDomain>

The domain data (horizontal axis) for the candlestick chart. String data will be treated as discrete labels, other data will be treated as continuous values.