Struct google_sheets4::api::ChartDateTimeRule [−][src]
Allows you to organize the date-time values in a source data column into buckets based on selected parts of their date or time values.
This type is not used in any activity, and only used as part of another schema.
Fields
type_: Option<String>The type of date-time grouping to apply.