Struct google_sheets4::api::CutPasteRequest [−][src]
Moves data from the source to the destination.
This type is not used in any activity, and only used as part of another schema.
Fields
destination: Option<GridCoordinate>The top-left coordinate where the data should be pasted.
paste_type: Option<String>What kind of data to paste. All the source data will be cut, regardless of what is pasted.
source: Option<GridRange>The source data to cut.