Struct google_sheets4::api::DataSourceParameter[][src]

pub struct DataSourceParameter {
    pub name: Option<String>,
    pub named_range_id: Option<String>,
    pub range: Option<GridRange>,
}

A parameter in a data source’s query. The parameter allows the user to pass in values from the spreadsheet into a query.

This type is not used in any activity, and only used as part of another schema.

Fields

name: Option<String>

Named parameter. Must be a legitimate identifier for the DataSource that supports it. For example, BigQuery identifier.

named_range_id: Option<String>

ID of a NamedRange. Its size must be 1x1.

range: Option<GridRange>

A range that contains the value of the parameter. Its size must be 1x1.