Struct google_sheets4::api::DataSourceRefreshMonthlySchedule[][src]

pub struct DataSourceRefreshMonthlySchedule {
    pub days_of_month: Option<Vec<i32>>,
    pub start_time: Option<TimeOfDay>,
}

A monthly schedule for data to refresh on specific days in the month in a given time interval.

This type is not used in any activity, and only used as part of another schema.

Fields

days_of_month: Option<Vec<i32>>

Days of the month to refresh. Only 1-28 are supported, mapping to the 1st to the 28th day. At lesat one day must be specified.

start_time: Option<TimeOfDay>

The start time of a time interval in which a data source refresh is scheduled. Only hours part is used. The time interval size defaults to that in the Sheets editor.