Struct google_sheets4::api::DataSourceRefreshWeeklySchedule[][src]

pub struct DataSourceRefreshWeeklySchedule {
    pub days_of_week: Option<Vec<String>>,
    pub start_time: Option<TimeOfDay>,
}

A weekly schedule for data to refresh on specific days in a given time interval.

This type is not used in any activity, and only used as part of another schema.

Fields

days_of_week: Option<Vec<String>>

Days of the week to refresh. At least one day must be specified.

start_time: Option<TimeOfDay>

The start time of a time interval in which a data source refresh is scheduled. Only hours part is used. The time interval size defaults to that in the Sheets editor.