Struct google_sheets4::api::DataSourceSpec[][src]

pub struct DataSourceSpec {
    pub big_query: Option<BigQueryDataSourceSpec>,
    pub parameters: Option<Vec<DataSourceParameter>>,
}

This specifies the details of the data source. For example, for BigQuery, this specifies information about the BigQuery source.

This type is not used in any activity, and only used as part of another schema.

Fields

big_query: Option<BigQueryDataSourceSpec>

A BigQueryDataSourceSpec.

parameters: Option<Vec<DataSourceParameter>>

The parameters of the data source, used when querying the data source.