Struct google_sheets4::api::FilterCriteria [−][src]
Criteria for showing/hiding rows in a filter or filter view.
This type is not used in any activity, and only used as part of another schema.
Fields
condition: Option<BooleanCondition>A condition that must be true for values to be shown. (This does not override hidden_values – if a value is listed there, it will still be hidden.)
Values that should be hidden.
visible_background_color: Option<Color>The background fill color to filter by; only cells with this fill color are shown. Mutually exclusive with visible_foreground_color.
visible_background_color_style: Option<ColorStyle>The background fill color to filter by; only cells with this fill color are shown. This field is mutually exclusive with visible_foreground_color, and must be set to an RGB-type color. If visible_background_color is also set, this field takes precedence.
visible_foreground_color: Option<Color>The foreground color to filter by; only cells with this foreground color are shown. Mutually exclusive with visible_background_color.
visible_foreground_color_style: Option<ColorStyle>The foreground color to filter by; only cells with this foreground color are shown. This field is mutually exclusive with visible_background_color, and must be set to an RGB-type color. If visible_foreground_color is also set, this field takes precedence.