Struct google_sheets4::api::FilterView [−][src]
A filter view.
This type is not used in any activity, and only used as part of another schema.
Fields
criteria: Option<HashMap<String, FilterCriteria>>The criteria for showing/hiding values per column. The map’s key is the column index, and the value is the criteria for that column. This field is deprecated in favor of filter_specs.
filter_specs: Option<Vec<FilterSpec>>The filter criteria for showing/hiding values per column. Both criteria and filter_specs are populated in responses. If both fields are specified in an update request, this field takes precedence.
filter_view_id: Option<i32>The ID of the filter view.
named_range_id: Option<String>The named range this filter view is backed by, if any. When writing, only one of range or named_range_id may be set.
range: Option<GridRange>The range this filter view covers. When writing, only one of range or named_range_id may be set.
sort_specs: Option<Vec<SortSpec>>The sort order per column. Later specifications are used when values are equal in the earlier specifications.
title: Option<String>The name of the filter view.