Struct google_sheets4::api::FindReplaceRequest [−][src]
Finds and replaces data in cells over a range, sheet, or all sheets.
This type is not used in any activity, and only used as part of another schema.
Fields
all_sheets: Option<bool>True to find/replace over all sheets.
find: Option<String>The value to search.
include_formulas: Option<bool>True if the search should include cells with formulas. False to skip cells with formulas.
match_case: Option<bool>True if the search is case sensitive.
match_entire_cell: Option<bool>True if the find value should match the entire cell.
range: Option<GridRange>The range to find/replace over.
replacement: Option<String>The value to use as the replacement.
search_by_regex: Option<bool>True if the find value is a regex. The regular expression and replacement should follow Java regex rules at https://docs.oracle.com/javase/8/docs/api/java/util/regex/Pattern.html. The replacement string is allowed to refer to capturing groups. For example, if one cell has the contents "Google Sheets" and another has "Google Docs", then searching for "o.* (.*)" with a replacement of "$1 Rocks" would change the contents of the cells to "GSheets Rocks" and "GDocs Rocks" respectively.
sheet_id: Option<i32>The sheet to find/replace over.