Struct google_sheets4::api::GridProperties [−][src]
Properties of a grid.
This type is not used in any activity, and only used as part of another schema.
Fields
column_count: Option<i32>The number of columns in the grid.
column_group_control_after: Option<bool>True if the column grouping control toggle is shown after the group.
frozen_column_count: Option<i32>The number of columns that are frozen in the grid.
frozen_row_count: Option<i32>The number of rows that are frozen in the grid.
hide_gridlines: Option<bool>True if the grid isn’t showing gridlines in the UI.
row_count: Option<i32>The number of rows in the grid.
row_group_control_after: Option<bool>True if the row grouping control toggle is shown after the group.