Struct google_sheets4::api::ManualRule[][src]

pub struct ManualRule {
    pub groups: Option<Vec<ManualRuleGroup>>,
}

Allows you to manually organize the values in a source data column into buckets with names of your choosing. For example, a pivot table that aggregates population by state: +—––+—————––+ | State | SUM of Population | +—––+—————––+ | AK | 0.7 | | AL | 4.8 | | AR | 2.9 | … +—––+—————––+ could be turned into a pivot table that aggregates population by time zone by providing a list of groups (for example, groupName = ‘Central’, items = [‘AL’, ‘AR’, ‘IA’, …]) to a manual group rule. Note that a similar effect could be achieved by adding a time zone column to the source data and adjusting the pivot table. +———–+—————––+ | Time Zone | SUM of Population | +———–+—————––+ | Central | 106.3 | | Eastern | 151.9 | | Mountain | 17.4 | … +———–+—————––+

This type is not used in any activity, and only used as part of another schema.

Fields

groups: Option<Vec<ManualRuleGroup>>

The list of group names and the corresponding items from the source data that map to each group name.