Struct google_sheets4::api::ManualRuleGroup [−][src]
A group name and a list of items from the source data that should be placed in the group with this name.
This type is not used in any activity, and only used as part of another schema.
Fields
group_name: Option<ExtendedValue>The group name, which must be a string. Each group in a given ManualRule must have a unique group name.
items: Option<Vec<ExtendedValue>>The items in the source data that should be placed into this group. Each item may be a string, number, or boolean. Items may appear in at most one group within a given ManualRule. Items that do not appear in any group will appear on their own.