Struct google_sheets4::api::NumberFormat [−][src]
The number format of a cell.
This type is not used in any activity, and only used as part of another schema.
Fields
pattern: Option<String>Pattern string used for formatting. If not set, a default pattern based on the user’s locale will be used if necessary for the given type. See the Date and Number Formats guide for more information about the supported patterns.
type_: Option<String>The type of the number format. When writing, this field must be set.