Struct google_sheets4::api::PointStyle[][src]

pub struct PointStyle {
    pub shape: Option<String>,
    pub size: Option<f64>,
}

The style of a point on the chart.

This type is not used in any activity, and only used as part of another schema.

Fields

shape: Option<String>

The point shape. If empty or unspecified, a default shape is used.

size: Option<f64>

The point size. If empty, a default size is used.