Struct google_sheets4::api::Sheet [−][src]
A sheet in a spreadsheet.
This type is not used in any activity, and only used as part of another schema.
Fields
banded_ranges: Option<Vec<BandedRange>>The banded (alternating colors) ranges on this sheet.
basic_filter: Option<BasicFilter>The filter on this sheet, if any.
charts: Option<Vec<EmbeddedChart>>The specifications of every chart on this sheet.
column_groups: Option<Vec<DimensionGroup>>All column groups on this sheet, ordered by increasing range start index, then by group depth.
conditional_formats: Option<Vec<ConditionalFormatRule>>The conditional format rules in this sheet.
data: Option<Vec<GridData>>Data in the grid, if this is a grid sheet. The number of GridData objects returned is dependent on the number of ranges requested on this sheet. For example, if this is representing Sheet1, and the spreadsheet was requested with ranges Sheet1!A1:C10 and Sheet1!D15:E20, then the first GridData will have a startRow/startColumn of 0, while the second one will have startRow 14 (zero-based row 15), and startColumn 3 (zero-based column D). For a DATA_SOURCE sheet, you can not request a specific range, the GridData contains all the values.
developer_metadata: Option<Vec<DeveloperMetadata>>The developer metadata associated with a sheet.
filter_views: Option<Vec<FilterView>>The filter views in this sheet.
merges: Option<Vec<GridRange>>The ranges that are merged together.
properties: Option<SheetProperties>The properties of the sheet.
protected_ranges: Option<Vec<ProtectedRange>>The protected ranges in this sheet.
row_groups: Option<Vec<DimensionGroup>>All row groups on this sheet, ordered by increasing range start index, then by group depth.
slicers: Option<Vec<Slicer>>The slicers on this sheet.