Struct google_sheets4::api::Slicer [−][src]
A slicer in a sheet.
This type is not used in any activity, and only used as part of another schema.
Fields
position: Option<EmbeddedObjectPosition>The position of the slicer. Note that slicer can be positioned only on existing sheet. Also, width and height of slicer can be automatically adjusted to keep it within permitted limits.
slicer_id: Option<i32>The ID of the slicer.
spec: Option<SlicerSpec>The specification of the slicer.