Struct google_sheets4::api::TreemapChartColorScale [−][src]
A color scale for a treemap chart.
This type is not used in any activity, and only used as part of another schema.
Fields
max_value_color: Option<Color>The background color for cells with a color value greater than or equal to maxValue. Defaults to #109618 if not specified.
max_value_color_style: Option<ColorStyle>The background color for cells with a color value greater than or equal to maxValue. Defaults to #109618 if not specified. If max_value_color is also set, this field takes precedence.
mid_value_color: Option<Color>The background color for cells with a color value at the midpoint between minValue and maxValue. Defaults to #efe6dc if not specified.
mid_value_color_style: Option<ColorStyle>The background color for cells with a color value at the midpoint between minValue and maxValue. Defaults to #efe6dc if not specified. If mid_value_color is also set, this field takes precedence.
min_value_color: Option<Color>The background color for cells with a color value less than or equal to minValue. Defaults to #dc3912 if not specified.
min_value_color_style: Option<ColorStyle>The background color for cells with a color value less than or equal to minValue. Defaults to #dc3912 if not specified. If min_value_color is also set, this field takes precedence.
no_data_color: Option<Color>The background color for cells that have no color data associated with them. Defaults to #000000 if not specified.
no_data_color_style: Option<ColorStyle>The background color for cells that have no color data associated with them. Defaults to #000000 if not specified. If no_data_color is also set, this field takes precedence.