Struct google_sheets4::api::TreemapChartSpec [−][src]
A Treemap chart.
This type is not used in any activity, and only used as part of another schema.
Fields
color_data: Option<ChartData>The data that determines the background color of each treemap data cell. This field is optional. If not specified, size_data is used to determine background colors. If specified, the data is expected to be numeric. color_scale will determine how the values in this data map to data cell background colors.
color_scale: Option<TreemapChartColorScale>The color scale for data cells in the treemap chart. Data cells are assigned colors based on their color values. These color values come from color_data, or from size_data if color_data is not specified. Cells with color values less than or equal to min_value will have minValueColor as their background color. Cells with color values greater than or equal to max_value will have maxValueColor as their background color. Cells with color values between min_value and max_value will have background colors on a gradient between minValueColor and maxValueColor, the midpoint of the gradient being midValueColor. Cells with missing or non-numeric color values will have noDataColor as their background color.
header_color: Option<Color>The background color for header cells.
header_color_style: Option<ColorStyle>The background color for header cells. If header_color is also set, this field takes precedence.
hide_tooltips: Option<bool>True to hide tooltips.
hinted_levels: Option<i32>The number of additional data levels beyond the labeled levels to be shown on the treemap chart. These levels are not interactive and are shown without their labels. Defaults to 0 if not specified.
labels: Option<ChartData>The data that contains the treemap cell labels.
levels: Option<i32>The number of data levels to show on the treemap chart. These levels are interactive and are shown with their labels. Defaults to 2 if not specified.
max_value: Option<f64>The maximum possible data value. Cells with values greater than this will have the same color as cells with this value. If not specified, defaults to the actual maximum value from color_data, or the maximum value from size_data if color_data is not specified.
min_value: Option<f64>The minimum possible data value. Cells with values less than this will have the same color as cells with this value. If not specified, defaults to the actual minimum value from color_data, or the minimum value from size_data if color_data is not specified.
parent_labels: Option<ChartData>The data the contains the treemap cells’ parent labels.
size_data: Option<ChartData>The data that determines the size of each treemap data cell. This data is expected to be numeric. The cells corresponding to non-numeric or missing data will not be rendered. If color_data is not specified, this data is used to determine data cell background colors as well.
text_format: Option<TextFormat>The text format for all labels on the chart.