pub struct TrimWhitespaceResponse {
pub cells_changed_count: Option<i32>,
}Expand description
The result of trimming whitespace in cells.
This type is not used in any activity, and only used as part of another schema.
Fields
cells_changed_count: Option<i32>The number of cells that were trimmed of whitespace.