Struct google_sheets4::api::UnmergeCellsRequest[][src]

pub struct UnmergeCellsRequest {
    pub range: Option<GridRange>,
}

Unmerges cells in the given range.

This type is not used in any activity, and only used as part of another schema.

Fields

range: Option<GridRange>

The range within which all cells should be unmerged. If the range spans multiple merges, all will be unmerged. The range must not partially span any merge.