Struct google_sheets4::api::UpdateBordersRequest [−][src]
Updates the borders of a range. If a field is not set in the request, that means the border remains as-is. For example, with two subsequent UpdateBordersRequest: 1. range: A1:A5 { top: RED, bottom: WHITE } 2. range: A1:A5 { left: BLUE } That would result in A1:A5 having a borders of { top: RED, bottom: WHITE, left: BLUE }. If you want to clear a border, explicitly set the style to NONE.
This type is not used in any activity, and only used as part of another schema.
Fields
bottom: Option<Border>The border to put at the bottom of the range.
inner_horizontal: Option<Border>The horizontal border to put within the range.
inner_vertical: Option<Border>The vertical border to put within the range.
left: Option<Border>The border to put at the left of the range.
range: Option<GridRange>The range whose borders should be updated.
right: Option<Border>The border to put at the right of the range.
top: Option<Border>The border to put at the top of the range.