Struct google_sheets4::api::WaterfallChartSeries [−][src]
A single series of data for a waterfall chart.
This type is not used in any activity, and only used as part of another schema.
Fields
custom_subtotals: Option<Vec<WaterfallChartCustomSubtotal>>Custom subtotal columns appearing in this series. The order in which subtotals are defined is not significant. Only one subtotal may be defined for each data point.
data: Option<ChartData>The data being visualized in this series.
data_label: Option<DataLabel>Information about the data labels for this series.
hide_trailing_subtotal: Option<bool>True to hide the subtotal column from the end of the series. By default, a subtotal column will appear at the end of each series. Setting this field to true will hide that subtotal column for this series.
negative_columns_style: Option<WaterfallChartColumnStyle>Styles for all columns in this series with negative values.
positive_columns_style: Option<WaterfallChartColumnStyle>Styles for all columns in this series with positive values.
subtotal_columns_style: Option<WaterfallChartColumnStyle>Styles for all subtotal columns in this series.