Struct google_sheets4::DataFilter
source · pub struct DataFilter {
pub developer_metadata_lookup: Option<DeveloperMetadataLookup>,
pub a1_range: Option<String>,
pub grid_range: Option<GridRange>,
}Expand description
Filter that describes what data should be selected or returned from a request.
This type is not used in any activity, and only used as part of another schema.
Fields
developer_metadata_lookup: Option<DeveloperMetadataLookup>Selects data associated with the developer metadata matching the criteria described by this DeveloperMetadataLookup.
a1_range: Option<String>Selects data that matches the specified A1 range.
grid_range: Option<GridRange>Selects data that matches the range described by the GridRange.