pub struct DeveloperMetadataLocation {
pub location_type: Option<String>,
pub dimension_range: Option<DimensionRange>,
pub spreadsheet: Option<bool>,
pub sheet_id: Option<i32>,
}Expand description
A location where metadata may be associated in a spreadsheet.
This type is not used in any activity, and only used as part of another schema.
Fields
location_type: Option<String>The type of location this object represents. This field is read-only.
dimension_range: Option<DimensionRange>Represents the row or column when metadata is associated with a dimension. The specified DimensionRange must represent a single row or column; it cannot be unbounded or span multiple rows or columns.
spreadsheet: Option<bool>True when metadata is associated with an entire spreadsheet.
sheet_id: Option<i32>The ID of the sheet when metadata is associated with an entire sheet.