pub struct DeveloperMetadataLookup {
    pub metadata_location: Option<DeveloperMetadataLocation>,
    pub metadata_value: Option<String>,
    pub location_matching_strategy: Option<String>,
    pub location_type: Option<String>,
    pub metadata_id: Option<i32>,
    pub visibility: Option<String>,
    pub metadata_key: Option<String>,
}
Selects DeveloperMetadata that matches all of the specified fields. For example, if only a metadata ID is specified this considers the DeveloperMetadata with that particular unique ID. If a metadata key is specified, this considers all developer metadata with that key. If a key, visibility, and location type are all specified, this considers all developer metadata with that key and visibility that are associated with a location of that type. In general, this selects all DeveloperMetadata that matches the intersection of all the specified fields; any field or combination of fields may be specified.

This type is not used in any activity, and only used as part of another schema.

Fields

metadata_location: Option<DeveloperMetadataLocation>

Limits the selected developer metadata to those entries associated with the specified location. This field either matches exact locations or all intersecting locations according the specified locationMatchingStrategy.

metadata_value: Option<String>

Limits the selected developer metadata to that which has a matching DeveloperMetadata.metadata_value.

location_matching_strategy: Option<String>

Determines how this lookup matches the location. If this field is specified as EXACT, only developer metadata associated on the exact location specified is matched. If this field is specified to INTERSECTING, developer metadata associated on intersecting locations is also matched. If left unspecified, this field assumes a default value of INTERSECTING. If this field is specified, a metadataLocation must also be specified.

location_type: Option<String>

Limits the selected developer metadata to those entries which are associated with locations of the specified type. For example, when this field is specified as ROW this lookup only considers developer metadata associated on rows. If the field is left unspecified, all location types are considered. This field cannot be specified as SPREADSHEET when the locationMatchingStrategy is specified as INTERSECTING or when the metadataLocation is specified as a non-spreadsheet location: spreadsheet metadata cannot intersect any other developer metadata location. This field also must be left unspecified when the locationMatchingStrategy is specified as EXACT.

metadata_id: Option<i32>

Limits the selected developer metadata to that which has a matching DeveloperMetadata.metadata_id.

visibility: Option<String>

Limits the selected developer metadata to that which has a matching DeveloperMetadata.visibility. If left unspecified, all developer metadata visibile to the requesting project is considered.

metadata_key: Option<String>

Limits the selected developer metadata to that which has a matching DeveloperMetadata.metadata_key.