pub struct DimensionRange {
    pub end_index: Option<i32>,
    pub start_index: Option<i32>,
    pub dimension: Option<String>,
    pub sheet_id: Option<i32>,
}
A range along a single dimension on a sheet. All indexes are zero-based. Indexes are half open: the start index is inclusive and the end index is exclusive. Missing indexes indicate the range is unbounded on that side.

This type is not used in any activity, and only used as part of another schema.

Fields

end_index: Option<i32>

The end (exclusive) of the span, or not set if unbounded.

start_index: Option<i32>

The start (inclusive) of the span, or not set if unbounded.

dimension: Option<String>

The dimension of the span.

sheet_id: Option<i32>

The sheet this span is on.