pub struct GridRange {
    pub end_row_index: Option<i32>,
    pub end_column_index: Option<i32>,
    pub sheet_id: Option<i32>,
    pub start_column_index: Option<i32>,
    pub start_row_index: Option<i32>,
}
A range on a sheet. All indexes are zero-based. Indexes are half open, e.g the start index is inclusive and the end index is exclusive – [start_index, end_index). Missing indexes indicate the range is unbounded on that side.

For example, if "Sheet1" is sheet ID 0, then:

Sheet1!A1:A1 == sheet_id: 0, start_row_index: 0, end_row_index: 1, start_column_index: 0, end_column_index: 1

Sheet1!A3:B4 == sheet_id: 0, start_row_index: 2, end_row_index: 4, start_column_index: 0, end_column_index: 2

Sheet1!A:B == sheet_id: 0, start_column_index: 0, end_column_index: 2

Sheet1!A5:B == sheet_id: 0, start_row_index: 4, start_column_index: 0, end_column_index: 2

Sheet1 == sheet_id:0

The start index must always be less than or equal to the end index. If the start index equals the end index, then the range is empty. Empty ranges are typically not meaningful and are usually rendered in the UI as #REF!.

This type is not used in any activity, and only used as part of another schema.

Fields

end_row_index: Option<i32>

The end row (exclusive) of the range, or not set if unbounded.

end_column_index: Option<i32>

The end column (exclusive) of the range, or not set if unbounded.

sheet_id: Option<i32>

The sheet this range is on.

start_column_index: Option<i32>

The start column (inclusive) of the range, or not set if unbounded.

start_row_index: Option<i32>

The start row (inclusive) of the range, or not set if unbounded.