pub struct MatchedDeveloperMetadata {
    pub data_filters: Option<Vec<DataFilter>>,
    pub developer_metadata: Option<DeveloperMetadata>,
}
A developer metadata entry and the data filters specified in the original request that matched it.

This type is not used in any activity, and only used as part of another schema.

Fields

data_filters: Option<Vec<DataFilter>>

All filters matching the returned developer metadata.

developer_metadata: Option<DeveloperMetadata>

The developer metadata matching the specified filters.