Struct google_sheets4::api::BatchGetValuesByDataFilterRequest [−][src]
The request for retrieving a range of values in a spreadsheet selected by a set of DataFilters.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
data_filters: Option<Vec<DataFilter>>The data filters used to match the ranges of values to retrieve. Ranges that match any of the specified data filters are included in the response.
date_time_render_option: Option<String>How dates, times, and durations should be represented in the output. This is ignored if value_render_option is FORMATTED_VALUE. The default dateTime render option is [DateTimeRenderOption.SERIAL_NUMBER].
major_dimension: Option<String>The major dimension that results should use. For example, if the spreadsheet data is: A1=1,B1=2,A2=3,B2=4, then a request that selects that range and sets majorDimension=ROWS returns [[1,2],[3,4]], whereas a request that sets majorDimension=COLUMNS returns [[1,3],[2,4]].
value_render_option: Option<String>How values should be represented in the output. The default render option is ValueRenderOption.FORMATTED_VALUE.