Struct google_sheets4::api::ClearValuesResponse [−][src]
The response when clearing a range of values in a spreadsheet.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- values clear spreadsheets (response)
Fields
cleared_range: Option<String>The range (in A1 notation) that was cleared. (If the request was for an unbounded range or a ranger larger than the bounds of the sheet, this will be the actual range that was cleared, bounded to the sheet’s limits.)
spreadsheet_id: Option<String>The spreadsheet the updates were applied to.