Struct google_sheets4::api::DataExecutionStatus [−][src]
The data execution status. A data execution is created to sync a data source object with the latest data from a DataSource. It is usually scheduled to run at background, you can check its state to tell if an execution completes There are several scenarios where a data execution is triggered to run: * Adding a data source creates an associated data source sheet as well as a data execution to sync the data from the data source to the sheet. * Updating a data source creates a data execution to refresh the associated data source sheet similarly. * You can send refresh request to explicitly refresh one or multiple data source objects.
This type is not used in any activity, and only used as part of another schema.
Fields
error_code: Option<String>The error code.
error_message: Option<String>The error message, which may be empty.
last_refresh_time: Option<String>Gets the time the data last successfully refreshed.
state: Option<String>The state of the data execution.