Struct google_sheets4::api::DataFilterValueRange [−][src]
A range of values whose location is specified by a DataFilter.
This type is not used in any activity, and only used as part of another schema.
Fields
data_filter: Option<DataFilter>The data filter describing the location of the values in the spreadsheet.
major_dimension: Option<String>The major dimension of the values.
values: Option<Vec<Vec<String>>>The data to be written. If the provided values exceed any of the ranges matched by the data filter then the request fails. If the provided values are less than the matched ranges only the specified values are written, existing values in the matched ranges remain unaffected.