Struct google_sheets4::api::DuplicateSheetRequest [−][src]
Duplicates the contents of a sheet.
This type is not used in any activity, and only used as part of another schema.
Fields
insert_sheet_index: Option<i32>The zero-based index where the new sheet should be inserted. The index of all sheets after this are incremented.
new_sheet_id: Option<i32>If set, the ID of the new sheet. If not set, an ID is chosen. If set, the ID must not conflict with any existing sheet ID. If set, it must be non-negative.
new_sheet_name: Option<String>The name of the new sheet. If empty, a new name is chosen for you.
source_sheet_id: Option<i32>The sheet to duplicate. If the source sheet is of DATA_SOURCE type, its backing DataSource is also duplicated and associated with the new copy of the sheet. No data execution is triggered, the grid data of this sheet is also copied over but only available after the batch request completes.