Struct google_sheets4::api::PivotGroupLimit [−][src]
The count limit on rows or columns in the pivot group.
This type is not used in any activity, and only used as part of another schema.
Fields
apply_order: Option<i32>The order in which the group limit is applied to the pivot table. Pivot group limits are applied from lower to higher order number. Order numbers are normalized to consecutive integers from 0. For write request, to fully customize the applying orders, all pivot group limits should have this field set with an unique number. Otherwise, the order is determined by the index in the PivotTable.rows list and then the PivotTable.columns list.
count_limit: Option<i32>The count limit.