Struct google_sheets4::api::PivotValue [−][src]
The definition of how a value in a pivot table should be calculated.
This type is not used in any activity, and only used as part of another schema.
Fields
calculated_display_type: Option<String>If specified, indicates that pivot values should be displayed as the result of a calculation with another pivot value. For example, if calculated_display_type is specified as PERCENT_OF_GRAND_TOTAL, all the pivot values are displayed as the percentage of the grand total. In the Sheets editor, this is referred to as “Show As” in the value section of a pivot table.
data_source_column_reference: Option<DataSourceColumnReference>The reference to the data source column that this value reads from.
formula: Option<String>A custom formula to calculate the value. The formula must start with an = character.
name: Option<String>A name to use for the value.
source_column_offset: Option<i32>The column offset of the source range that this value reads from. For example, if the source was C10:E15, a sourceColumnOffset of 0 means this value refers to column C, whereas the offset 1 would refer to column D.
summarize_function: Option<String>A function to summarize the value. If formula is set, the only supported values are SUM and CUSTOM. If sourceColumnOffset is set, then CUSTOM is not supported.