Struct google_sheets4::api::TextRotation [−][src]
The rotation applied to text in a cell.
This type is not used in any activity, and only used as part of another schema.
Fields
angle: Option<i32>The angle between the standard orientation and the desired orientation. Measured in degrees. Valid values are between -90 and 90. Positive angles are angled upwards, negative are angled downwards. Note: For LTR text direction positive angles are in the counterclockwise direction, whereas for RTL they are in the clockwise direction
vertical: Option<bool>If true, text reads top to bottom, but the orientation of individual characters is unchanged. For example: | V | | e | | r | | t | | i | | c | | a | | l |