Struct google_sheets4::DeveloperMetadata

source ·
pub struct DeveloperMetadata {
    pub metadata_id: Option<i32>,
    pub metadata_value: Option<String>,
    pub location: Option<DeveloperMetadataLocation>,
    pub visibility: Option<String>,
    pub metadata_key: Option<String>,
}
Developer metadata associated with a location or object in a spreadsheet. Developer metadata may be used to associate arbitrary data with various parts of a spreadsheet and will remain associated at those locations as they move around and the spreadsheet is edited. For example, if developer metadata is associated with row 5 and another row is then subsequently inserted above row 5, that original metadata will still be associated with the row it was first associated with (what is now row 6). If the associated object is deleted its metadata is deleted too.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

metadata_id: Option<i32>

The spreadsheet-scoped unique ID that identifies the metadata. IDs may be specified when metadata is created, otherwise one will be randomly generated and assigned. Must be positive.

metadata_value: Option<String>

Data associated with the metadata’s key.

location: Option<DeveloperMetadataLocation>

The location where the metadata is associated.

visibility: Option<String>

The metadata visibility. Developer metadata must always have a visibility specified.

metadata_key: Option<String>

The metadata key. There may be multiple metadata in a spreadsheet with the same key. Developer metadata must always have a key specified.